@@ -40,6 +40,7 @@ import os
 import re
 import shutil
 import urllib
+import ftplib
 
 #### geodeZYX modules
 from geodezyx import conv
@@ -513,7 +514,10 @@ def downloader_wrap(intup):
 
 def multi_downloader_rinex(statdico,archive_dir,startdate,enddate,
                            archtype ='stat',parallel_download=4,
-                           sorted_mode=False,user='',passwd=''):
+                           sorted_mode=False,user='',passwd='',
+                           filter_ftp_crawler=True,
+                           path_ftp_crawled_files_save=None,
+                           path_ftp_crawled_files_load=None):
     """
     Parameters
     ----------
@@ -576,7 +580,24 @@ def multi_downloader_rinex(statdico,archive_dir,startdate,enddate,
 
     user & passwd : str
         user & password for a locked server
-
+        
+    filter_ftp_crawler : bool
+        use an improved FTP crawler to find which files actually exist
+        to accelerate the download. If path_ftp_crawled_files_load is given, 
+        use this loaded list.
+        
+    path_ftp_crawled_files_save : str
+        will save at the given path (directory+filname) a pickle containing the 
+        list of the existing RINEXs found on the server by the FTP crawler.
+        It allows to use this list directly if one face a timeout during 
+        the download part.
+        NB for advanced users: the pickle is a tuple (urllist,savedirlist)
+    
+    path_ftp_crawled_files_load : str
+        load and use the list of the existing RINEXs found on the FTP server,
+        generated by a previous run of the FTP crawler (called by 
+        multi_downloader_rinex or directly by ftp_files_crawler).
+        overrides an internal call of ftp_files_crawler.
 
     Returns
     -------
@@ -643,11 +664,28 @@ def multi_downloader_rinex(statdico,archive_dir,startdate,enddate,
     #savedirlist = [x for (y,x) in sorted(zip(urllist,savedirlist))]
     #urllist     = sorted(urllist)
     
-    urllist,savedirlist = utils.sort_binom_list(urllist,savedirlist)
+    try:
+        urllist,savedirlist = utils.sort_binom_list(urllist,savedirlist)
+    except TypeError as err:
+        print("ERR: unable to sort the URL and the save directory") 
+        print("TIP: you maybe asked for servers with & without password in the same statdico") 
+        raise err
 
     print(" ... done")
     print(len(urllist),"potential RINEXs")
 
+    ### Use of the advanced FTP Crawler
+    if filter_ftp_crawler:
+        if path_ftp_crawled_files_load:
+            urllist,savedirlist = utils.pickle_loader(path_ftp_crawled_files_load)
+        else:
+            urllist,savedirlist = ftp_files_crawler(urllist,savedirlist)
+            if path_ftp_crawled_files_save:
+                savetup = (urllist,savedirlist)
+                utils.pickle_saver(savetup,
+                                   full_path=path_ftp_crawled_files_save)
+
+
     if sorted_mode:
         results = [pool.apply_async(downloader , args=(u,sd)) for u,sd in zip(urllist,savedirlist)]
     else:
@@ -1546,3 +1584,114 @@ def multi_downloader_orbs_clks_2(archive_dir,startdate,enddate,
     
     pool.close()
     return Localfiles_lis
+
+
+ #  _____       _                        _    __                  _   _                 
+ # |_   _|     | |                      | |  / _|                | | (_)                
+ #   | |  _ __ | |_ ___ _ __ _ __   __ _| | | |_ _   _ _ __   ___| |_ _  ___  _ __  ___ 
+ #   | | | '_ \| __/ _ \ '__| '_ \ / _` | | |  _| | | | '_ \ / __| __| |/ _ \| '_ \/ __|
+ #  _| |_| | | | ||  __/ |  | | | | (_| | | | | | |_| | | | | (__| |_| | (_) | | | \__ \
+ # |_____|_| |_|\__\___|_|  |_| |_|\__,_|_| |_|  \__,_|_| |_|\___|\__|_|\___/|_| |_|___/
+                                                                                      
+def _ftp_dir_list_files(ftp_obj_in):
+    files = []
+    try:
+        files = ftp_obj_in.nlst()
+    except ftplib.error_perm as resp:
+        if str(resp) == "550 No files found":
+            print("No files in this directory",ftp_obj_in.pwd())
+        else:
+            raise
+    return files
+
+
+def ftp_files_crawler(urllist,savedirlist):
+    """
+    filter urllist,savedirlist generated with multi_downloader_rinex with an
+    optimized FTP crawl
+
+    """
+    ### create a DataFrame based on the urllist and savedirlist lists
+    DF = pd.concat((pd.DataFrame(urllist),pd.DataFrame(savedirlist)),axis=1)
+    DF_orig = DF.copy()
+    
+    ### rename the columns
+    if DF.shape[1] == 4:
+        loginftp = True 
+        DF.columns = ('url','user','pass','savedir')
+    else:
+        loginftp = False
+        DF.columns = ('url','savedir')
+        DF['user'] = "anonymous"
+        DF['pass'] = ""
+        
+    ### Do the correct split for the URLs
+    DF = DF.sort_values('url')
+    DF["url"]      = DF['url'].str.replace("ftp://","")
+    DF["dirname"]  = DF["url"].apply(os.path.dirname)
+    DF["basename"] = DF["url"].apply(os.path.basename)
+    DF["root"]     = [e.split("/")[0] for e in DF["dirname"].values]
+    DF["dir"]      = [e1.replace(e2,"")[1:] for (e1,e2) in zip(DF["dirname"],
+                                                                   DF["root"])]
+    DF["bool"] = False
+    
+    #### Initialisation of the 1st variables for the loop
+    prev_row_ftpobj = DF.iloc[0]
+    prev_row_cwd    = DF.iloc[0]
+    FTP_files_list = []
+    count_loop = 0  # restablish the connexion after 50 loops (avoid freezing)
+    #### Initialisation of the FTP object
+    FTPobj = ftplib.FTP(prev_row_ftpobj.root,
+                        prev_row_ftpobj.user, 
+                        prev_row_ftpobj['pass'])
+    
+    for irow,row in DF.iterrows():
+        #print(irow)
+        count_loop += 1
+        
+        ####### we recreate a new FTP object if the root URL is not the same
+        if row.root != prev_row_ftpobj.root or count_loop > 20:
+    
+            FTPobj = ftplib.FTP(row.root,
+                                row.user, 
+                                row['pass'])
+            
+            prev_row_ftpobj = row
+            count_loop = 0
+            
+        ####### we recreate a new file list if the date path is not the same        
+        if prev_row_cwd.dir != row.dir:
+            print("INFO:","chdir",row.dirname)
+            FTPobj.cwd("/")
+    
+            try: #### we try to change for the right folder
+                FTPobj.cwd(row.dir)
+            except: #### If not possible, then no file in the list
+                FTP_files_list = []
+              
+            FTP_files_list = _ftp_dir_list_files(FTPobj)
+            prev_row_cwd = row 
+               
+        ####### we check if the files is avaiable
+        if row.basename in FTP_files_list:
+            DF.loc[irow,'bool'] = True
+            print("INFO:",row.basename ,"found on server :)")
+        else:
+            DF.loc[irow,'bool'] = False
+            print("WARN:",row.basename ,"not found on server :(")
+    
+    
+    DFgood = DF[DF['bool']].copy()
+    
+    DFgood['url'] = 'ftp://' + DFgood['url']  
+    
+    ### generate the outputs
+    if loginftp:
+        urllist_out = list(zip(DFgood.url,DFgood.user,DFgood['pass']))
+    else:
+        urllist_out = list(DFgood.url)    
+    
+    savedirlist_out = list(DFgood.savedir)
+    
+    return urllist_out, savedirlist_out
+
